==> mongodb-ui-components-4.2.6.tgz: package/src/footer/language-picker.js <==
import {h, Component} from 'preact'
import {chatIcon} from './icons'

export default class LanguagePicker extends Component {
  constructor (props) {
    super(props)
    this.toggle = this.toggle.bind(this)
    this.state = {
      isOpen: false,
      activeCode: 'en'
    }
  }

  componentDidMount () {
    const {languages} = this.props
    const urlCode = window.location.pathname.split('/').pop()

    for (let i = 0, l = languages.length; i < l; i++) {
      const [, code] = languages[i]
      if (urlCode === code) {
        return this.setState({activeCode: code})
      }
    }
  }

  toggle () {
    this.setState({isOpen: !this.state.isOpen})
  }

  onLangSelect (code) {
    window.location.href = `/${code}`
  }

  render (props, {isOpen, activeCode}) {
    return (
      <div class='relative h-50 m-b-20 user-select-none' style={{
        height: '24px',
        visibility: props.visible === true ? null : 'hidden'
      }}>
        <div class='fl fl-center' style={{cursor: 'pointer'}} onClick={this.toggle}>
          {chatIcon}
          <small class='m-l-10'><strong>English</strong></small>
        </div>

        {isOpen &&
        <div
          class='absolute w-min-90 bg-white radius p-v-10 p-h-20'
          style={{bottom: '40px', left: '-10px', cursor: 'pointer'}}>
          {props.languages
            .filter(([lang, code]) => code !== activeCode)
            .map(([lang, code]) =>
              <small
                class='disp-block hover-green'
                style={{color: '#1A1A1A', padding: '2px'}}
                onClick={() => this.onLangSelect(code)}>
                {lang}
              </small>
            )}
          <div class='arrow-down absolute' style={{
            bottom: '-10px',
            left: 'calc(50% - 10px)'
          }} />
        </div>}
      </div>
    )
  }
}

==> mongodb-ui-components-4.2.16.tgz: package/src/footer/language-picker.js <==
import {h, Component} from 'preact'
import {chatIcon} from './icons'

export default class LanguagePicker extends Component {
  constructor (props) {
    super(props)
    this.toggle = this.toggle.bind(this)
    this.state = {
      isOpen: false,
      activeCode: 'en'
    }
  }

  componentDidMount () {
    const {languages} = this.props
    const urlCode = window.location.pathname.split('/').pop()

    for (let i = 0, l = languages.length; i < l; i++) {
      const [, code] = languages[i]
      if (urlCode === code) {
        return this.setState({activeCode: code})
      }
    }
  }

  toggle () {
    this.setState({isOpen: !this.state.isOpen})
  }

  onLangSelect (code) {
    window.location.href = `/${code}`
  }

  render (props, {isOpen, activeCode}) {
    if (props.visible !== true) return null

    return (
      <div class='relative h-50 m-b-40 user-select-none' style={{height: '24px'}}>
        <div class='fl fl-center' style={{cursor: 'pointer'}} onClick={this.toggle}>
          {chatIcon}
          <small class='m-l-10'><strong>English</strong></small>
        </div>

        {isOpen &&
        <div
          class='absolute w-min-90 bg-white radius p-v-10 p-h-20'
          style={{bottom: '40px', left: '-10px', cursor: 'pointer'}}>
          {props.languages
            .filter(([lang, code]) => code !== activeCode)
            .map(([lang, code]) =>
              <small
                class='disp-block hover-green'
                style={{color: '#1A1A1A', padding: '2px'}}
                onClick={() => this.onLangSelect(code)}>
                {lang}
              </small>
            )}
          <div class='arrow-down absolute' style={{
            bottom: '-10px',
            left: 'calc(50% - 10px)'
          }} />
        </div>}
      </div>
    )
  }
}
